@@ -133,8 +133,8 @@ SEXP R_symeig_spm(SEXP x, SEXP onlyvals_, SEXP descending)
   int ptct;
   int info;
   
-  const float_len_t m = NROWS(x);
-  const float_len_t n = NCOLS(x);
+  const float_len_t m = (float_len_t) NROWS(x);
+  const float_len_t n = (float_len_t) NCOLS(x);
   if (m != n)
     error("non-square matrix in 'eigen'\n");
   
